Class: Google::Apis::TranscoderV1::Input

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/transcoder_v1/classes.rb,
lib/google/apis/transcoder_v1/representations.rb,
lib/google/apis/transcoder_v1/representations.rb

Overview

Input asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Input

Returns a new instance of Input.



1308
1309
1310
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1308

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesGoogle::Apis::TranscoderV1::InputAttributes

Input attributes that provide additional information about the input asset. Corresponds to the JSON property attributes



1286
1287
1288
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1286

def attributes
  @attributes
end

#keyString

A unique key for this input. Must be specified when using advanced mapping and edit lists. Corresponds to the JSON property key

Returns:

  • (String)


1292
1293
1294
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1292

def key
  @key
end

#preprocessing_configGoogle::Apis::TranscoderV1::PreprocessingConfig

Preprocessing configurations. Corresponds to the JSON property preprocessingConfig



1297
1298
1299
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1297

def preprocessing_config
  @preprocessing_config
end

#uriString

URI of the media. Input files must be at least 5 seconds in duration and stored in Cloud Storage (for example, gs://bucket/inputs/file.mp4). If empty, the value is populated from Job.input_uri. See Supported input and output formats. Corresponds to the JSON property uri

Returns:

  • (String)


1306
1307
1308
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1306

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1313
1314
1315
1316
1317
1318
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1313

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @key = args[:key] if args.key?(:key)
  @preprocessing_config = args[:preprocessing_config] if args.key?(:preprocessing_config)
  @uri = args[:uri] if args.key?(:uri)
end