Class: Google::Apis::TranscoderV1::InputAttributes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/transcoder_v1/classes.rb,
lib/google/apis/transcoder_v1/representations.rb,
lib/google/apis/transcoder_v1/representations.rb

Overview

Input attributes that provide additional information about the input asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InputAttributes

Returns a new instance of InputAttributes.



1330
1331
1332
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1330

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#track_definitionsArray<Google::Apis::TranscoderV1::TrackDefinition>

Optional. A list of track definitions for the input asset. Corresponds to the JSON property trackDefinitions



1328
1329
1330
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1328

def track_definitions
  @track_definitions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1335
1336
1337
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1335

def update!(**args)
  @track_definitions = args[:track_definitions] if args.key?(:track_definitions)
end