Class: Google::Apis::TranscoderV1::MuxStream

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/transcoder_v1/classes.rb,
lib/google/apis/transcoder_v1/representations.rb,
lib/google/apis/transcoder_v1/representations.rb

Overview

Multiplexing settings for output stream.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MuxStream

Returns a new instance of MuxStream.



1759
1760
1761
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1759

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containerString

The container format. The default is mp4 Supported streaming formats: - ts

  • fmp4- the corresponding file extension is .m4s Supported standalone file formats: - mp4 - mp3 - ogg - vtt See also: Supported input and output formats Corresponds to the JSON property container

Returns:

  • (String)


1723
1724
1725
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1723

def container
  @container
end

#elementary_streamsArray<String>

List of ElementaryStream.key values multiplexed in this stream. Corresponds to the JSON property elementaryStreams

Returns:

  • (Array<String>)


1728
1729
1730
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1728

def elementary_streams
  @elementary_streams
end

#encryption_idString

Identifier of the encryption configuration to use. If omitted, output will be unencrypted. Corresponds to the JSON property encryptionId

Returns:

  • (String)


1734
1735
1736
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1734

def encryption_id
  @encryption_id
end

#file_nameString

The name of the generated file. The default is MuxStream.key with the extension suffix corresponding to the MuxStream.container. Individual segments also have an incremental 10-digit zero-padded suffix starting from 0 before the extension, such as mux_stream0000000123.ts. Corresponds to the JSON property fileName

Returns:

  • (String)


1742
1743
1744
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1742

def file_name
  @file_name
end

#fmp4Google::Apis::TranscoderV1::Fmp4Config

fmp4 container configuration. Corresponds to the JSON property fmp4



1747
1748
1749
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1747

def fmp4
  @fmp4
end

#keyString

A unique key for this multiplexed stream. Corresponds to the JSON property key

Returns:

  • (String)


1752
1753
1754
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1752

def key
  @key
end

#segment_settingsGoogle::Apis::TranscoderV1::SegmentSettings

Segment settings for ts, fmp4 and vtt. Corresponds to the JSON property segmentSettings



1757
1758
1759
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1757

def segment_settings
  @segment_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1764
1765
1766
1767
1768
1769
1770
1771
1772
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1764

def update!(**args)
  @container = args[:container] if args.key?(:container)
  @elementary_streams = args[:elementary_streams] if args.key?(:elementary_streams)
  @encryption_id = args[:encryption_id] if args.key?(:encryption_id)
  @file_name = args[:file_name] if args.key?(:file_name)
  @fmp4 = args[:fmp4] if args.key?(:fmp4)
  @key = args[:key] if args.key?(:key)
  @segment_settings = args[:segment_settings] if args.key?(:segment_settings)
end