Class: Google::Apis::TranscoderV1::Pad

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/transcoder_v1/classes.rb,
lib/google/apis/transcoder_v1/representations.rb,
lib/google/apis/transcoder_v1/representations.rb

Overview

Pad filter configuration for the input video. The padded input video is scaled after padding with black to match the output resolution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Pad

Returns a new instance of Pad.



1872
1873
1874
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1872

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bottom_pixelsFixnum

The number of pixels to add to the bottom. The default is 0. Corresponds to the JSON property bottomPixels

Returns:

  • (Fixnum)


1855
1856
1857
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1855

def bottom_pixels
  @bottom_pixels
end

#left_pixelsFixnum

The number of pixels to add to the left. The default is 0. Corresponds to the JSON property leftPixels

Returns:

  • (Fixnum)


1860
1861
1862
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1860

def left_pixels
  @left_pixels
end

#right_pixelsFixnum

The number of pixels to add to the right. The default is 0. Corresponds to the JSON property rightPixels

Returns:

  • (Fixnum)


1865
1866
1867
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1865

def right_pixels
  @right_pixels
end

#top_pixelsFixnum

The number of pixels to add to the top. The default is 0. Corresponds to the JSON property topPixels

Returns:

  • (Fixnum)


1870
1871
1872
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1870

def top_pixels
  @top_pixels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1877
1878
1879
1880
1881
1882
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1877

def update!(**args)
  @bottom_pixels = args[:bottom_pixels] if args.key?(:bottom_pixels)
  @left_pixels = args[:left_pixels] if args.key?(:left_pixels)
  @right_pixels = args[:right_pixels] if args.key?(:right_pixels)
  @top_pixels = args[:top_pixels] if args.key?(:top_pixels)
end