Class: Google::Apis::TranscoderV1::PreprocessingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/transcoder_v1/classes.rb,
lib/google/apis/transcoder_v1/representations.rb,
lib/google/apis/transcoder_v1/representations.rb

Overview

Preprocessing configurations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreprocessingConfig

Returns a new instance of PreprocessingConfig.



1942
1943
1944
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audioGoogle::Apis::TranscoderV1::Audio

Audio preprocessing configuration. Corresponds to the JSON property audio



1905
1906
1907
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1905

def audio
  @audio
end

#colorGoogle::Apis::TranscoderV1::Color

Color preprocessing configuration. Note: This configuration is not supported. Corresponds to the JSON property color



1911
1912
1913
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1911

def color
  @color
end

#cropGoogle::Apis::TranscoderV1::Crop

Video cropping configuration for the input video. The cropped input video is scaled to match the output resolution. Corresponds to the JSON property crop



1917
1918
1919
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1917

def crop
  @crop
end

#deblockGoogle::Apis::TranscoderV1::Deblock

Deblock preprocessing configuration. Note: This configuration is not supported. Corresponds to the JSON property deblock



1923
1924
1925
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1923

def deblock
  @deblock
end

#deinterlaceGoogle::Apis::TranscoderV1::Deinterlace

Deinterlace configuration for input video. Corresponds to the JSON property deinterlace



1928
1929
1930
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1928

def deinterlace
  @deinterlace
end

#denoiseGoogle::Apis::TranscoderV1::Denoise

Denoise preprocessing configuration. Note: This configuration is not supported. Corresponds to the JSON property denoise



1934
1935
1936
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1934

def denoise
  @denoise
end

#padGoogle::Apis::TranscoderV1::Pad

Pad filter configuration for the input video. The padded input video is scaled after padding with black to match the output resolution. Corresponds to the JSON property pad



1940
1941
1942
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1940

def pad
  @pad
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1947
1948
1949
1950
1951
1952
1953
1954
1955
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1947

def update!(**args)
  @audio = args[:audio] if args.key?(:audio)
  @color = args[:color] if args.key?(:color)
  @crop = args[:crop] if args.key?(:crop)
  @deblock = args[:deblock] if args.key?(:deblock)
  @deinterlace = args[:deinterlace] if args.key?(:deinterlace)
  @denoise = args[:denoise] if args.key?(:denoise)
  @pad = args[:pad] if args.key?(:pad)
end