Class: Google::Apis::TranscoderV1::SpriteSheet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/transcoder_v1/classes.rb,
lib/google/apis/transcoder_v1/representations.rb,
lib/google/apis/transcoder_v1/representations.rb

Overview

Sprite sheet configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SpriteSheet

Returns a new instance of SpriteSheet.



2126
2127
2128
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2126

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#column_countFixnum

The maximum number of sprites per row in a sprite sheet. The default is 0, which indicates no maximum limit. Corresponds to the JSON property columnCount

Returns:

  • (Fixnum)


2049
2050
2051
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2049

def column_count
  @column_count
end

#end_time_offsetString

End time in seconds, relative to the output file timeline. When end_time_offset is not specified, the sprites are generated until the end of the output file. Corresponds to the JSON property endTimeOffset

Returns:

  • (String)


2056
2057
2058
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2056

def end_time_offset
  @end_time_offset
end

#file_prefixString

Required. File name prefix for the generated sprite sheets. Each sprite sheet has an incremental 10-digit zero-padded suffix starting from 0 before the extension, such as sprite_sheet0000000123.jpeg. Corresponds to the JSON property filePrefix

Returns:

  • (String)


2063
2064
2065
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2063

def file_prefix
  @file_prefix
end

#formatString

Format type. The default is jpeg. Supported formats: - jpeg Corresponds to the JSON property format

Returns:

  • (String)


2068
2069
2070
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2068

def format
  @format
end

#intervalString

Starting from 0s, create sprites at regular intervals. Specify the interval value in seconds. Corresponds to the JSON property interval

Returns:

  • (String)


2074
2075
2076
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2074

def interval
  @interval
end

#qualityFixnum

The quality of the generated sprite sheet. Enter a value between 1 and 100, where 1 is the lowest quality and 100 is the highest quality. The default is

  1. A high quality value corresponds to a low image data compression ratio. Corresponds to the JSON property quality

Returns:

  • (Fixnum)


2081
2082
2083
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2081

def quality
  @quality
end

#row_countFixnum

The maximum number of rows per sprite sheet. When the sprite sheet is full, a new sprite sheet is created. The default is 0, which indicates no maximum limit. Corresponds to the JSON property rowCount

Returns:

  • (Fixnum)


2088
2089
2090
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2088

def row_count
  @row_count
end

#sprite_height_pixelsFixnum

Required. The height of sprite in pixels. Must be an even integer. To preserve the source aspect ratio, set the SpriteSheet.sprite_height_pixels field or the SpriteSheet.sprite_width_pixels field, but not both (the API will automatically calculate the missing field). For portrait videos that contain horizontal ASR and rotation metadata, provide the height, in pixels, per the horizontal ASR. The API calculates the width per the horizontal ASR. The API detects any rotation metadata and swaps the requested height and width for the output. Corresponds to the JSON property spriteHeightPixels

Returns:

  • (Fixnum)


2100
2101
2102
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2100

def sprite_height_pixels
  @sprite_height_pixels
end

#sprite_width_pixelsFixnum

Required. The width of sprite in pixels. Must be an even integer. To preserve the source aspect ratio, set the SpriteSheet.sprite_width_pixels field or the SpriteSheet.sprite_height_pixels field, but not both (the API will automatically calculate the missing field). For portrait videos that contain horizontal ASR and rotation metadata, provide the width, in pixels, per the horizontal ASR. The API calculates the height per the horizontal ASR. The API detects any rotation metadata and swaps the requested height and width for the output. Corresponds to the JSON property spriteWidthPixels

Returns:

  • (Fixnum)


2112
2113
2114
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2112

def sprite_width_pixels
  @sprite_width_pixels
end

#start_time_offsetString

Start time in seconds, relative to the output file timeline. Determines the first sprite to pick. The default is 0s. Corresponds to the JSON property startTimeOffset

Returns:

  • (String)


2118
2119
2120
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2118

def start_time_offset
  @start_time_offset
end

#total_countFixnum

Total number of sprites. Create the specified number of sprites distributed evenly across the timeline of the output media. The default is 100. Corresponds to the JSON property totalCount

Returns:

  • (Fixnum)


2124
2125
2126
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2124

def total_count
  @total_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2131

def update!(**args)
  @column_count = args[:column_count] if args.key?(:column_count)
  @end_time_offset = args[:end_time_offset] if args.key?(:end_time_offset)
  @file_prefix = args[:file_prefix] if args.key?(:file_prefix)
  @format = args[:format] if args.key?(:format)
  @interval = args[:interval] if args.key?(:interval)
  @quality = args[:quality] if args.key?(:quality)
  @row_count = args[:row_count] if args.key?(:row_count)
  @sprite_height_pixels = args[:sprite_height_pixels] if args.key?(:sprite_height_pixels)
  @sprite_width_pixels = args[:sprite_width_pixels] if args.key?(:sprite_width_pixels)
  @start_time_offset = args[:start_time_offset] if args.key?(:start_time_offset)
  @total_count = args[:total_count] if args.key?(:total_count)
end