Class: Google::Apis::TranscoderV1::TrackDefinition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/transcoder_v1/classes.rb,
lib/google/apis/transcoder_v1/representations.rb,
lib/google/apis/transcoder_v1/representations.rb

Overview

Track definition for the input asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TrackDefinition

Returns a new instance of TrackDefinition.



2290
2291
2292
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2290

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detect_languagesBoolean Also known as: detect_languages?

Optional. Whether to automatically detect the languages present in the track. If true, the system will attempt to identify all the languages present in the track and populate the languages field. Corresponds to the JSON property detectLanguages

Returns:

  • (Boolean)


2267
2268
2269
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2267

def detect_languages
  @detect_languages
end

#detected_languagesArray<String>

Output only. A list of languages detected in the input asset, represented by a BCP 47 language code, such as "en-US" or "sr-Latn". For more information, see https://www.unicode.org/reports/tr35/#Unicode_locale_identifier. This field is only populated if the detect_languages field is set to true. Corresponds to the JSON property detectedLanguages

Returns:

  • (Array<String>)


2276
2277
2278
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2276

def detected_languages
  @detected_languages
end

#input_trackFixnum

The input track. Corresponds to the JSON property inputTrack

Returns:

  • (Fixnum)


2281
2282
2283
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2281

def input_track
  @input_track
end

#languagesArray<String>

Optional. A list of languages spoken in the input asset, represented by a BCP 47 language code, such as "en-US" or "sr-Latn". For more information, see https://www.unicode.org/reports/tr35/#Unicode_locale_identifier. Corresponds to the JSON property languages

Returns:

  • (Array<String>)


2288
2289
2290
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2288

def languages
  @languages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2295
2296
2297
2298
2299
2300
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2295

def update!(**args)
  @detect_languages = args[:detect_languages] if args.key?(:detect_languages)
  @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
  @input_track = args[:input_track] if args.key?(:input_track)
  @languages = args[:languages] if args.key?(:languages)
end