Class: Google::Apis::TranscoderV1::Vp9CodecSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/transcoder_v1/classes.rb,
lib/google/apis/transcoder_v1/representations.rb,
lib/google/apis/transcoder_v1/representations.rb

Overview

VP9 codec settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Vp9CodecSettings

Returns a new instance of Vp9CodecSettings.



2433
2434
2435
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bitrate_bpsFixnum

Required. The video bitrate in bits per second. The minimum value is 1,000. The maximum value is 480,000,000. Corresponds to the JSON property bitrateBps

Returns:

  • (Fixnum)


2342
2343
2344
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2342

def bitrate_bps
  @bitrate_bps
end

#crf_levelFixnum

Target CRF level. Must be between 10 and 36, where 10 is the highest quality and 36 is the most efficient compression. The default is 21. Note: This field is not supported. Corresponds to the JSON property crfLevel

Returns:

  • (Fixnum)


2349
2350
2351
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2349

def crf_level
  @crf_level
end

#frame_rateFloat

Required. The target video frame rate in frames per second (FPS). Must be less than or equal to 120. Corresponds to the JSON property frameRate

Returns:

  • (Float)


2355
2356
2357
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2355

def frame_rate
  @frame_rate
end

#frame_rate_conversion_strategyString

Optional. Frame rate conversion strategy for desired frame rate. The default is DOWNSAMPLE. Corresponds to the JSON property frameRateConversionStrategy

Returns:

  • (String)


2361
2362
2363
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2361

def frame_rate_conversion_strategy
  @frame_rate_conversion_strategy
end

#gop_durationString

Select the GOP size based on the specified duration. The default is 3s. Note that gopDuration must be less than or equal to segmentDuration, and segmentDuration must be divisible by gopDuration. Corresponds to the JSON property gopDuration

Returns:

  • (String)


2369
2370
2371
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2369

def gop_duration
  @gop_duration
end

#gop_frame_countFixnum

Select the GOP size based on the specified frame count. Must be greater than zero. Corresponds to the JSON property gopFrameCount

Returns:

  • (Fixnum)


2375
2376
2377
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2375

def gop_frame_count
  @gop_frame_count
end

#height_pixelsFixnum

The height of the video in pixels. Must be an even integer. When not specified, the height is adjusted to match the specified width and input aspect ratio. If both are omitted, the input height is used. For portrait videos that contain horizontal ASR and rotation metadata, provide the height, in pixels, per the horizontal ASR. The API calculates the width per the horizontal ASR. The API detects any rotation metadata and swaps the requested height and width for the output. Corresponds to the JSON property heightPixels

Returns:

  • (Fixnum)


2386
2387
2388
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2386

def height_pixels
  @height_pixels
end

#hlgGoogle::Apis::TranscoderV1::Vp9ColorFormatHlg

Convert the input video to a Hybrid Log Gamma (HLG) video. Corresponds to the JSON property hlg



2391
2392
2393
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2391

def hlg
  @hlg
end

#pixel_formatString

Pixel format to use. The default is yuv420p. Supported pixel formats: - yuv420p pixel format - yuv422p pixel format - yuv444p pixel format - yuv420p10 10-bit HDR pixel format - yuv422p10 10-bit HDR pixel format - yuv444p10 10-bit HDR pixel format - yuv420p12 12-bit HDR pixel format - yuv422p12 12-bit HDR pixel format - yuv444p12 12-bit HDR pixel format Corresponds to the JSON property pixelFormat

Returns:

  • (String)


2400
2401
2402
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2400

def pixel_format
  @pixel_format
end

#profileString

Enforces the specified codec profile. The following profiles are supported: * profile0 (default) * profile1 * profile2 * profile3 The available options are WebM-compatible. Note that certain values for this field may cause the transcoder to override other fields you set in the Vp9CodecSettings message. Corresponds to the JSON property profile

Returns:

  • (String)


2409
2410
2411
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2409

def profile
  @profile
end

#rate_control_modeString

Specify the mode. The default is vbr. Supported rate control modes: - vbr - variable bitrate Corresponds to the JSON property rateControlMode

Returns:

  • (String)


2415
2416
2417
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2415

def rate_control_mode
  @rate_control_mode
end

#sdrGoogle::Apis::TranscoderV1::Vp9ColorFormatSdr

Convert the input video to a Standard Dynamic Range (SDR) video. Corresponds to the JSON property sdr



2420
2421
2422
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2420

def sdr
  @sdr
end

#width_pixelsFixnum

The width of the video in pixels. Must be an even integer. When not specified, the width is adjusted to match the specified height and input aspect ratio. If both are omitted, the input width is used. For portrait videos that contain horizontal ASR and rotation metadata, provide the width, in pixels, per the horizontal ASR. The API calculates the height per the horizontal ASR. The API detects any rotation metadata and swaps the requested height and width for the output. Corresponds to the JSON property widthPixels

Returns:

  • (Fixnum)


2431
2432
2433
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2431

def width_pixels
  @width_pixels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
2448
2449
2450
2451
2452
# File 'lib/google/apis/transcoder_v1/classes.rb', line 2438

def update!(**args)
  @bitrate_bps = args[:bitrate_bps] if args.key?(:bitrate_bps)
  @crf_level = args[:crf_level] if args.key?(:crf_level)
  @frame_rate = args[:frame_rate] if args.key?(:frame_rate)
  @frame_rate_conversion_strategy = args[:frame_rate_conversion_strategy] if args.key?(:frame_rate_conversion_strategy)
  @gop_duration = args[:gop_duration] if args.key?(:gop_duration)
  @gop_frame_count = args[:gop_frame_count] if args.key?(:gop_frame_count)
  @height_pixels = args[:height_pixels] if args.key?(:height_pixels)
  @hlg = args[:hlg] if args.key?(:hlg)
  @pixel_format = args[:pixel_format] if args.key?(:pixel_format)
  @profile = args[:profile] if args.key?(:profile)
  @rate_control_mode = args[:rate_control_mode] if args.key?(:rate_control_mode)
  @sdr = args[:sdr] if args.key?(:sdr)
  @width_pixels = args[:width_pixels] if args.key?(:width_pixels)
end