Class: Google::Apis::TranscoderV1::Job
- Inherits:
-
Object
- Object
- Google::Apis::TranscoderV1::Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/transcoder_v1/classes.rb,
lib/google/apis/transcoder_v1/representations.rb,
lib/google/apis/transcoder_v1/representations.rb
Overview
Transcoding job resource.
Instance Attribute Summary collapse
-
#batch_mode_priority ⇒ Fixnum
The processing priority of a batch job.
-
#config ⇒ Google::Apis::TranscoderV1::JobConfig
Job configuration Corresponds to the JSON property
config. -
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::TranscoderV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#fill_content_gaps ⇒ Boolean
(also: #fill_content_gaps?)
Optional.
-
#input_uri ⇒ String
Input only.
-
#labels ⇒ Hash<String,String>
The labels associated with this job.
-
#mode ⇒ String
The processing mode of the job.
-
#name ⇒ String
The resource name of the job.
-
#optimization ⇒ String
Optional.
-
#output_uri ⇒ String
Input only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#template_id ⇒ String
Input only.
-
#ttl_after_completion_days ⇒ Fixnum
Job time to live value in days, which will be effective after job completion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Job
constructor
A new instance of Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Job
Returns a new instance of Job.
1448 1449 1450 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1448 def initialize(**args) update!(**args) end |
Instance Attribute Details
#batch_mode_priority ⇒ Fixnum
The processing priority of a batch job. This field can only be set for batch
mode jobs. The default value is 0. This value cannot be negative. Higher
values correspond to higher priorities for the job.
Corresponds to the JSON property batchModePriority
1349 1350 1351 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1349 def batch_mode_priority @batch_mode_priority end |
#config ⇒ Google::Apis::TranscoderV1::JobConfig
Job configuration
Corresponds to the JSON property config
1354 1355 1356 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1354 def config @config end |
#create_time ⇒ String
Output only. The time the job was created.
Corresponds to the JSON property createTime
1359 1360 1361 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1359 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the transcoding finished.
Corresponds to the JSON property endTime
1364 1365 1366 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1364 def end_time @end_time end |
#error ⇒ Google::Apis::TranscoderV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1374 1375 1376 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1374 def error @error end |
#fill_content_gaps ⇒ Boolean Also known as: fill_content_gaps?
Optional. Insert silence and duplicate frames when timestamp gaps are detected
in a given stream.
Corresponds to the JSON property fillContentGaps
1380 1381 1382 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1380 def fill_content_gaps @fill_content_gaps end |
#input_uri ⇒ String
Input only. Specify the input_uri to populate empty uri fields in each
element of Job.config.inputs or JobTemplate.config.inputs when using
template. URI of the media. Input files must be at least 5 seconds in duration
and stored in Cloud Storage (for example, gs://bucket/inputs/file.mp4). See
Supported input and output formats.
Corresponds to the JSON property inputUri
1391 1392 1393 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1391 def input_uri @input_uri end |
#labels ⇒ Hash<String,String>
The labels associated with this job. You can use these to organize and group
your jobs.
Corresponds to the JSON property labels
1397 1398 1399 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1397 def labels @labels end |
#mode ⇒ String
The processing mode of the job. The default is PROCESSING_MODE_INTERACTIVE.
Corresponds to the JSON property mode
1402 1403 1404 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1402 def mode @mode end |
#name ⇒ String
The resource name of the job. Format: projects/project_number/locations/
location/jobs/job`
Corresponds to the JSON propertyname`
1408 1409 1410 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1408 def name @name end |
#optimization ⇒ String
Optional. The optimization strategy of the job. The default is AUTODETECT.
Corresponds to the JSON property optimization
1413 1414 1415 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1413 def optimization @optimization end |
#output_uri ⇒ String
Input only. Specify the output_uri to populate an empty Job.config.output.
uri or JobTemplate.config.output.uri when using template. URI for the
output file(s). For example, gs://my-bucket/outputs/. See Supported input
and output formats.
Corresponds to the JSON property outputUri
1422 1423 1424 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1422 def output_uri @output_uri end |
#start_time ⇒ String
Output only. The time the transcoding started.
Corresponds to the JSON property startTime
1427 1428 1429 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1427 def start_time @start_time end |
#state ⇒ String
Output only. The current state of the job.
Corresponds to the JSON property state
1432 1433 1434 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1432 def state @state end |
#template_id ⇒ String
Input only. Specify the template_id to use for populating Job.config. The
default is preset/web-hd, which is the only supported preset. User defined
JobTemplate: job_template_id
Corresponds to the JSON property templateId
1439 1440 1441 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1439 def template_id @template_id end |
#ttl_after_completion_days ⇒ Fixnum
Job time to live value in days, which will be effective after job completion.
Job should be deleted automatically after the given TTL. Enter a value between
1 and 90. The default is 30.
Corresponds to the JSON property ttlAfterCompletionDays
1446 1447 1448 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1446 def ttl_after_completion_days @ttl_after_completion_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1453 def update!(**args) @batch_mode_priority = args[:batch_mode_priority] if args.key?(:batch_mode_priority) @config = args[:config] if args.key?(:config) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @fill_content_gaps = args[:fill_content_gaps] if args.key?(:fill_content_gaps) @input_uri = args[:input_uri] if args.key?(:input_uri) @labels = args[:labels] if args.key?(:labels) @mode = args[:mode] if args.key?(:mode) @name = args[:name] if args.key?(:name) @optimization = args[:optimization] if args.key?(:optimization) @output_uri = args[:output_uri] if args.key?(:output_uri) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @template_id = args[:template_id] if args.key?(:template_id) @ttl_after_completion_days = args[:ttl_after_completion_days] if args.key?(:ttl_after_completion_days) end |