Class: Google::Apis::TranscoderV1::Pad
- Inherits:
-
Object
- Object
- Google::Apis::TranscoderV1::Pad
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/transcoder_v1/classes.rb,
lib/google/apis/transcoder_v1/representations.rb,
lib/google/apis/transcoder_v1/representations.rb
Overview
Pad filter configuration for the input video. The padded input video is scaled after padding with black to match the output resolution.
Instance Attribute Summary collapse
-
#bottom_pixels ⇒ Fixnum
The number of pixels to add to the bottom.
-
#left_pixels ⇒ Fixnum
The number of pixels to add to the left.
-
#right_pixels ⇒ Fixnum
The number of pixels to add to the right.
-
#top_pixels ⇒ Fixnum
The number of pixels to add to the top.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Pad
constructor
A new instance of Pad.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Pad
Returns a new instance of Pad.
1872 1873 1874 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1872 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bottom_pixels ⇒ Fixnum
The number of pixels to add to the bottom. The default is 0.
Corresponds to the JSON property bottomPixels
1855 1856 1857 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1855 def bottom_pixels @bottom_pixels end |
#left_pixels ⇒ Fixnum
The number of pixels to add to the left. The default is 0.
Corresponds to the JSON property leftPixels
1860 1861 1862 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1860 def left_pixels @left_pixels end |
#right_pixels ⇒ Fixnum
The number of pixels to add to the right. The default is 0.
Corresponds to the JSON property rightPixels
1865 1866 1867 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1865 def right_pixels @right_pixels end |
#top_pixels ⇒ Fixnum
The number of pixels to add to the top. The default is 0.
Corresponds to the JSON property topPixels
1870 1871 1872 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1870 def top_pixels @top_pixels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1877 1878 1879 1880 1881 1882 |
# File 'lib/google/apis/transcoder_v1/classes.rb', line 1877 def update!(**args) @bottom_pixels = args[:bottom_pixels] if args.key?(:bottom_pixels) @left_pixels = args[:left_pixels] if args.key?(:left_pixels) @right_pixels = args[:right_pixels] if args.key?(:right_pixels) @top_pixels = args[:top_pixels] if args.key?(:top_pixels) end |